@@ -176,7 +176,7 @@ void RoomTreeModel::connectRoomSignals(NeoChatRoom *room)
         refreshRoomRoles(room);
     });
     connect(room, &Room::addedMessages, this, [this, room] {
-        refreshRoomRoles(room, {SubtitleTextRole, LastActiveTimeRole});
+        refreshRoomRoles(room, {SubtitleTextRole});
     });
     connect(room, &Room::pendingEventMerged, this, [this, room] {
         refreshRoomRoles(room, {SubtitleTextRole});
@@ -274,7 +274,6 @@ QHash<int, QByteArray> RoomTreeModel::roleNames() const
     roles[CategoryRole] = "category";
     roles[ContextNotificationCountRole] = "contextNotificationCount";
     roles[HasHighlightNotificationsRole] = "hasHighlightNotifications";
-    roles[LastActiveTimeRole] = "lastActiveTime";
     roles[JoinStateRole] = "joinState";
     roles[CurrentRoomRole] = "currentRoom";
     roles[SubtitleTextRole] = "subtitleText";
@@ -284,8 +283,6 @@ QHash<int, QByteArray> RoomTreeModel::roleNames() const
     roles[IsDirectChat] = "isDirectChat";
     roles[DelegateTypeRole] = "delegateType";
     roles[IconRole] = "icon";
-    roles[AttentionRole] = "attention";
-    roles[FavouriteRole] = "favourite";
     roles[RoomTypeRole] = "roomType";
     return roles;
 }
@@ -304,9 +301,9 @@ QVariant RoomTreeModel::data(const QModelIndex &index, int role) const
         }
         if (role == DelegateTypeRole) {
             if (index.row() == NeoChatRoomType::AddDirect) {
-                return QStringLiteral("addDirect");
+                return u"addDirect"_s;
             }
-            return QStringLiteral("section");
+            return u"section"_s;
         }
         if (role == IconRole) {
             return NeoChatRoomType::typeIconName(index.row());
@@ -341,12 +338,9 @@ QVariant RoomTreeModel::data(const QModelIndex &index, int role) const
     if (role == HasHighlightNotificationsRole) {
         return room->highlightCount() > 0 && room->contextAwareNotificationCount() > 0;
     }
-    if (role == LastActiveTimeRole) {
-        return room->lastActiveTime();
-    }
     if (role == JoinStateRole) {
         if (!room->successorId().isEmpty()) {
-            return QStringLiteral("upgraded");
+            return u"upgraded"_s;
         }
         return QVariant::fromValue(room->joinState());
     }
@@ -354,6 +348,12 @@ QVariant RoomTreeModel::data(const QModelIndex &index, int role) const
         return QVariant::fromValue(room);
     }
     if (role == SubtitleTextRole) {
+        if (room->isInvite()) {
+            if (room->isDirectChat()) {
+                return i18nc("@info:label", "Invited you to chat");
+            }
+            return i18nc("@info:label", "%1 invited you", room->member(room->invitingUserId()).displayName());
+        }
         if (room->lastEvent() == nullptr || room->lastEventIsSpoiler()) {
             return QString();
         }
@@ -378,13 +378,7 @@ QVariant RoomTreeModel::data(const QModelIndex &index, int role) const
         return room->isDirectChat();
     }
     if (role == DelegateTypeRole) {
-        return QStringLiteral("normal");
-    }
-    if (role == AttentionRole) {
-        return room->notificationCount() + room->highlightCount() > 0;
-    }
-    if (role == FavouriteRole) {
-        return room->isFavourite();
+        return u"normal"_s;
     }
     if (role == RoomTypeRole) {
         if (room->creation()) {
